merge_warmstart_teacher_traces_deterministic

Function merge_warmstart_teacher_traces_deterministic 

pub fn merge_warmstart_teacher_traces_deterministic<I>(
    traces: &mut Vec<WarmStartExactJhTeacherTrace>,
    incoming: I,
) -> (usize, Vec<WarmStartExactJhTeacherTrace>)
Merge teacher traces into traces, returning the number and payload of inserted traces.

Existing and incoming traces are canonicalized as a deterministic set before insertion, so callers may pass traces in arbitrary order.